pub enum SchemaChange {
CreateTable(TableDef),
DropTable(TableDef),
AddColumn {
table_name: String,
column: ColumnDef,
},
DropColumn {
table_name: String,
column_name: String,
},
}Expand description
A single schema change operation.
Variants
CreateTable(TableDef)
A new table needs to be created (includes all columns).
DropTable(TableDef)
An existing table needs to be dropped.
AddColumn
A new column needs to be added to an existing table.
DropColumn
A column needs to be removed from an existing table.