schema_diff

Function schema_diff 

pub fn schema_diff(from: &YAuthSchema, to: &YAuthSchema) -> Vec<SchemaChange>
Compute the diff between two schemas.

from is the previous schema state, to is the desired state. Returns a list of changes needed to go from from to to.